summaryrefslogtreecommitdiff
path: root/chromium/components/security_interstitials/content/unsafe_resource.cc
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2020-01-20 13:40:20 +0100
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2020-01-22 12:41:23 +0000
commit7961cea6d1041e3e454dae6a1da660b453efd238 (patch)
treec0eeb4a9ff9ba32986289c1653d9608e53ccb444 /chromium/components/security_interstitials/content/unsafe_resource.cc
parentb7034d0803538058e5c9d904ef03cf5eab34f6ef (diff)
downloadqtwebengine-chromium-7961cea6d1041e3e454dae6a1da660b453efd238.tar.gz
BASELINE: Update Chromium to 78.0.3904.130
Change-Id: If185e0c0061b3437531c97c9c8c78f239352a68b Reviewed-by: Allan Sandfeld Jensen <allan.jensen@qt.io>
Diffstat (limited to 'chromium/components/security_interstitials/content/unsafe_resource.cc')
-rw-r--r--chromium/components/security_interstitials/content/unsafe_resource.cc9
1 files changed, 6 insertions, 3 deletions
diff --git a/chromium/components/security_interstitials/content/unsafe_resource.cc b/chromium/components/security_interstitials/content/unsafe_resource.cc
index a22e6bef5d1..de6daf0b9b8 100644
--- a/chromium/components/security_interstitials/content/unsafe_resource.cc
+++ b/chromium/components/security_interstitials/content/unsafe_resource.cc
@@ -50,9 +50,12 @@ bool UnsafeResource::IsMainPageLoadBlocked() const {
case safe_browsing::SB_THREAT_TYPE_BLOCKED_AD_REDIRECT:
// Ad sampling happens in the background.
case safe_browsing::SB_THREAT_TYPE_AD_SAMPLE:
- // Sign-in password reuse warning happens after the page is finished
- // loading.
- case safe_browsing::SB_THREAT_TYPE_SIGN_IN_PASSWORD_REUSE:
+ // Chrome GAIA signed in and syncing password reuse warning happens after
+ // the page is finished loading.
+ case safe_browsing::SB_THREAT_TYPE_SIGNED_IN_SYNC_PASSWORD_REUSE:
+ // Chrome GAIA signed in and non-syncing password reuse warning happens
+ // after the page is finished loading.
+ case safe_browsing::SB_THREAT_TYPE_SIGNED_IN_NON_SYNC_PASSWORD_REUSE:
// Enterprise password reuse warning happens after the page is finished
// loading.
case safe_browsing::SB_THREAT_TYPE_ENTERPRISE_PASSWORD_REUSE: